@@ -208,8 +208,7 @@ void PlayerManager::play(const QString &file)
 {
     CollectionListItem *item = CollectionList::instance()->lookup(file);
     if(item) {
-        Playlist::setPlaying(item);
-        play(item->file());
+        Playlist::setPlaying(item); // Will reentrantly call play(FileHandle)
     }
 }
 
@@ -222,10 +221,8 @@ void PlayerManager::play()
         emit seeked(0);
     }
     else {
+        // Will reentrantly call play(FileHandle)
         m_playlistInterface->playNext();
-        const auto file = m_playlistInterface->currentFile();
-
-        play(file);
     }
 }
 
@@ -445,16 +442,23 @@ void PlayerManager::setVolume(qreal volume)
 void PlayerManager::setupAudio()
 {
     using namespace Phonon;
-    connect(m_output, &AudioOutput::mutedChanged,  this, &PlayerManager::slotMutedChanged);
-    connect(m_output, &AudioOutput::volumeChanged, this, &PlayerManager::setVolume);
+    connect(m_output, &AudioOutput::mutedChanged,
+            this, &PlayerManager::slotMutedChanged);
+    connect(m_output, &AudioOutput::volumeChanged,
+            this, &PlayerManager::setVolume);
 
-    connect(m_media, &MediaObject::stateChanged, this, &PlayerManager::slotStateChanged);
-    connect(m_media, &MediaObject::currentSourceChanged, this, &PlayerManager::trackHasChanged);
-    connect(m_media, &MediaObject::totalTimeChanged, this, &PlayerManager::slotLength);
-    connect(m_media, &MediaObject::tick, this, &PlayerManager::slotTick);
-    connect(m_media, &MediaObject::aboutToFinish, this, &PlayerManager::trackAboutToFinish);
-    connect(m_media, &MediaObject::finished, this, &PlayerManager::slotFinished);
-    connect(m_media, &MediaObject::seekableChanged, this, &PlayerManager::slotSeekableChanged);
+    connect(m_media, &MediaObject::stateChanged,
+            this, &PlayerManager::slotStateChanged);
+    connect(m_media, &MediaObject::currentSourceChanged,
+            this, &PlayerManager::trackHasChanged);
+    connect(m_media, &MediaObject::totalTimeChanged,
+            this, &PlayerManager::slotLength);
+    connect(m_media, &MediaObject::tick,
+            this, &PlayerManager::slotTick);
+    connect(m_media, &MediaObject::finished,
+            this, &PlayerManager::slotFinished);
+    connect(m_media, &MediaObject::seekableChanged,
+            this, &PlayerManager::slotSeekableChanged);
 
     m_media->setTickInterval(100);
 }
@@ -497,18 +501,4 @@ void PlayerManager::trackHasChanged(const Phonon::MediaSource &newSource)
     }
 }
 
-void PlayerManager::trackAboutToFinish()
-{
-    // Called when playback is in progress and a track is about to finish, gives us a
-    // chance to keep audio playback going without Phonon entering StoppedState
-    if(!m_playlistInterface)
-        return;
-
-    m_playlistInterface->playNext();
-    const auto file = m_playlistInterface->currentFile();
-
-    if(!file.isNull())
-        m_media->enqueue(QUrl::fromLocalFile(file.absFilePath()));
-}
-
 // vim: set et sw=4 tw=0 sta:
